Index: src/Kconfig
===================================================================
--- src/Kconfig	(revision 5643)
+++ src/Kconfig	(working copy)
@@ -83,6 +83,7 @@
 config USE_OPTION_TABLE
 	bool "Use CMOS for configuration values"
 	default n
+        depends on HAVE_OPTION_TABLE
 	help
 	  Enable this option if coreboot shall read options from the "CMOS"
 	  NVRAM instead of using hard coded values.
Index: src/include/pc80/mc146818rtc.h
===================================================================
--- src/include/pc80/mc146818rtc.h	(revision 5643)
+++ src/include/pc80/mc146818rtc.h	(working copy)
@@ -86,10 +86,15 @@
  * in option_table.h
  */
 
+#ifndef CONFIG_USE_OPTION_TABLE
+#define CONFIG_USE_OPTION_TABLE 0
+#endif
+
 #if !defined(ASSEMBLY) && !defined(__PRE_RAM__)
 void rtc_init(int invalid);
-#if CONFIG_USE_OPTION_TABLE == 1
+#if CONFIG_USE_OPTION_TABLE
 int get_option(void *dest, const char *name);
+inline unsigned read_option(unsigned start, unsigned size, unsigned def);
 #else
 static inline int get_option(void *dest __attribute__((unused)),
 	const char *name __attribute__((unused))) { return -2; }
Index: src/pc80/serial.c
===================================================================
--- src/pc80/serial.c	(revision 5643)
+++ src/pc80/serial.c	(working copy)
@@ -1,6 +1,13 @@
 #include <lib.h> /* Prototypes */
 #include <arch/io.h>
 
+#if CONFIG_HAVE_OPTION_TABLE
+#include "option_table.h"
+#include "pc80/mc146818rtc.h"
+#else
+#define CONFIG_USE_OPTION_TABLE 0
+#endif
+
 /* Base Address */
 #ifndef CONFIG_TTYS0_BASE
 #define CONFIG_TTYS0_BASE 0x3f8
@@ -80,7 +87,7 @@
 	outb(0x01, CONFIG_TTYS0_BASE + UART_FCR);
 	/* Set Baud Rate Divisor to 12 ==> 115200 Baud */
 	outb(0x80 | UART_LCS, CONFIG_TTYS0_BASE + UART_LCR);
-#if CONFIG_USE_OPTION_TABLE == 1
+#if CONFIG_USE_OPTION_TABLE
 	static const unsigned char divisor[] = { 1,2,3,6,12,24,48,96 };
 	unsigned ttys0_div, ttys0_index;
 	ttys0_index = read_option(CMOS_VSTART_baud_rate, CMOS_VLEN_baud_rate, 0);
@@ -101,7 +108,7 @@
 extern void uart8250_init(unsigned base_port, unsigned divisor, unsigned lcs);
 void uart_init(void)
 {
-#if CONFIG_USE_OPTION_TABLE == 1
+#if CONFIG_USE_OPTION_TABLE
         static const unsigned char divisor[] = { 1,2,3,6,12,24,48,96 };
         unsigned ttys0_div, ttys0_index;
         ttys0_index = read_option(CMOS_VSTART_baud_rate, CMOS_VLEN_baud_rate, 0);
Index: src/pc80/mc146818rtc_early.c
===================================================================
--- src/pc80/mc146818rtc_early.c	(revision 5643)
+++ src/pc80/mc146818rtc_early.c	(working copy)
@@ -1,3 +1,4 @@
+#include <arch/io.h>
 #include <pc80/mc146818rtc.h>
 #include <fallback.h>
 #if CONFIG_HAVE_OPTION_TABLE
@@ -43,7 +44,7 @@
 
 static int cmos_chksum_valid(void)
 {
-#if CONFIG_HAVE_OPTION_TABLE == 1
+#if CONFIG_HAVE_OPTION_TABLE
 	unsigned char addr;
 	unsigned long sum, old_sum;
 	sum = 0;
@@ -114,9 +115,9 @@
 	return (byte & (1<<1));
 }
 
-static inline unsigned read_option(unsigned start, unsigned size, unsigned def)
+inline unsigned read_option(unsigned start, unsigned size, unsigned def)
 {
-#if CONFIG_USE_OPTION_TABLE == 1
+#if CONFIG_USE_OPTION_TABLE
 	unsigned byte;
 	byte = cmos_read(start/8);
 	return (byte >> (start & 7U)) & ((1U << size) - 1U);
Index: src/pc80/Makefile.inc
===================================================================
--- src/pc80/Makefile.inc	(revision 5643)
+++ src/pc80/Makefile.inc	(working copy)
@@ -3,7 +3,7 @@
 obj-y += i8259.o
 obj-$(CONFIG_UDELAY_IO) += udelay_io.o
 obj-y += keyboard.o
-
+initobj-$(CONFIG_USE_OPTION_TABLE) += mc146818rtc_early.o
 initobj-$(CONFIG_USE_DCACHE_RAM) += serial.o
 subdirs-y += vga
 
Index: src/pc80/mc146818rtc.c
===================================================================
--- src/pc80/mc146818rtc.c	(revision 5643)
+++ src/pc80/mc146818rtc.c	(working copy)
@@ -203,7 +203,7 @@
 }
 
 
-#if CONFIG_USE_OPTION_TABLE == 1
+#if CONFIG_USE_OPTION_TABLE 
 /* This routine returns the value of the requested bits
 	input bit = bit count from the beginning of the cmos image
 	      length = number of bits to include in the value
